IProovEventCancelled class

The user cancelled iProov, either by pressing the close button at the top right, or sending the app to the background.

Implemented types

Constructors

IProovEventCancelled()
const

Properties

hashCode → int
The hash code for this object.
no setterinherited
isFinal → bool
no setteroverride
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited