IProovEventFailure class

The user was not successfully verified/enrolled, as their identity could not be verified, or there was another issue with their verification/enrollment.

Implemented types

Constructors

IProovEventFailure(String token, String reason, String feedbackCode, Image? frame)
const

Properties

feedbackCode → String
The feedback code relating to this error. For a list of possible failure codes, see:
final
frame → Image?
An optional image containing a single frame of the user, if enabled for your service provider.
final
hashCode → int
The hash code for this object.
no setterinherited
isFinal → bool
no setteroverride
reason → String
The reason for the failure which can be displayed directly to the user.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
token → String
The token passed back will be the same as the one passed in to the original call to iProov.launch.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited