CaptureOptions class

Options relating to the capture experience.

Constructors

CaptureOptions({GenuinePresenceAssuranceCaptureOptions? genuinePresenceAssurance, Camera? camera, FaceDetector? faceDetector})
const

Properties

camera → Camera?
The Camera to be used for the iProov scan.
final
faceDetector → FaceDetector?
The FaceDetector to be used locally for face detection.
final
genuinePresenceAssurance → GenuinePresenceAssuranceCaptureOptions?
Capture options relating specifically to Genuine Presence Assurance (GPA).
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited