GenuinePresenceAssuranceOptions class

Options relating to the appearance of the iProov user interface for GPA claims.

Annotations

Constructors

GenuinePresenceAssuranceOptions({Color? readyOvalStrokeColor, Color? notReadyOvalStrokeColor, bool? controlYPosition, bool? controlXPosition, bool? scanningPrompts})
const

Properties

controlXPosition → bool?
Whether to control x position of the face showing prompts.
final
controlYPosition → bool?
Whether to control y position of the face showing prompts.
final
hashCode → int
The hash code for this object.
no setterinherited
notReadyOvalStrokeColor → Color?
The Color to use for the oval stroke line when the scan is not ready to start.
final
readyOvalStrokeColor → Color?
The Color to use for the oval stroke line when the scan is ready to start.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
scanningPrompts → bool?
Show a prompt 'Scanning' during GPA scan and show a prompt 'Scan Completed' after GPA scan completes.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited