LineDrawingFilter class

Options relating to the camera preview based on iProov's traditional "canny" filter

Implemented types
Annotations

Constructors

LineDrawingFilter({LineDrawingFilterStyle? style, Color? foregroundColor, Color? backgroundColor})
const

Properties

backgroundColor → Color?
The Color to use for the background of the filter.
final
foregroundColor → Color?
The Color to use for the foreground of the filter.
final
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
style → LineDrawingFilterStyle?
The style to use for the filter. defaults to .shaded.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
override
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited