LivenessAssuranceOptions class

Options relating to the appearance of the iProov user interface for LA claims.

Annotations

Constructors

LivenessAssuranceOptions({Color? ovalStrokeColor, Color? completedOvalStrokeColor})
const

Properties

completedOvalStrokeColor → Color?
The Color to use for the oval stroke after LA scan completes.
final
hashCode → int
The hash code for this object.
no setterinherited
ovalStrokeColor → Color?
The Color to use for the oval stroke.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited