LivenessAssuranceUiOptions class

Options relating to the appearance of the iProov user interface for LA claims.

Constructors

LivenessAssuranceUiOptions({Color? primaryTintColor, Color? secondaryTintColor, Color? floatingPromptBackgroundColor, Color? overlayStrokeColor})
const

Properties

floatingPromptBackgroundColor → Color?
The Color to use for the background of the floating prompt (when enabled).
final
hashCode → int
The hash code for this object.
no setterinherited
overlayStrokeColor → Color?
The Color to use for the oval and reticle stroke lines.
final
primaryTintColor → Color?
The Color to use for the overlay tint when the scan is in progress.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
secondaryTintColor → Color?
The Color to use for the overlay tint when when the scan is completed.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited