Options class

Set options for the iProov SDK.

Most of these options are common to both Android and iOS, however, some are platform-specific.

All options are nullable and any options not set will default to their platform-defined default value.

Annotations

Constructors

Options({Filter? filter, Color? titleTextColor, Color? promptTextColor, Color? closeButtonTintColor, Image? closeButtonImage, String? title, String? fontPath, Image? logoImage, Color? promptBackgroundColor, bool? promptRoundedCorners, Color? surroundColor, List<String>? certificates, Duration? timeout, bool? enableScreenshots, Orientation? orientation, Color? headerBackgroundColor, bool? disableExteriorEffects, GenuinePresenceAssuranceOptions? genuinePresenceAssurance, LivenessAssuranceOptions? livenessAssurance})
const

Properties

certificates → List<String>?
A List of Strings containing the base64-encoded SHA-256 hash of each certificate's Subject Public Key Info.
final
closeButtonImage → Image?
A custom Image to be used for the close button which appears in the header bar at the top of the screen on the left hand side.
final
closeButtonTintColor → Color?
The Color to be applied to the closeButtonImage.
final
disableExteriorEffects → bool?
Whether the blur and vignette effect outside the oval should be disabled.
final
enableScreenshots → bool?
Whether screenshots should be allowed during the iProov scan process.
final
filter → Filter?
The Filter applied to the camera preview as either LineDrawingFilter or NaturalFilter.
final
fontPath → String?
Path to the font to use for the iProov UI. The font must be added to your app (TTF or OTF formats are supported).
final
genuinePresenceAssurance → GenuinePresenceAssuranceOptions?
Options relating specifically to Genuine Presence Assurance (GPA).
final
hashCode → int
The hash code for this object.
no setterinherited
headerBackgroundColor → Color?
The Color of the header bar.
final
livenessAssurance → LivenessAssuranceOptions?
Options relating specifically to Liveness Assurance (LA).
final
logoImage → Image?
A small logo Image to display in the header bar at the top of the screen on the right hand side.
final
orientation → Orientation?
Sets the orientation of the iProov UI.
final
promptBackgroundColor → Color?
The Color to use for the background of the prompt.
final
promptRoundedCorners → bool?
Whether the prompt should have rounded corners.
final
promptTextColor → Color?
The Color of text in prompt box.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
surroundColor → Color?
Color applied to the area outside the oval.
final
timeout → Duration?
The network timeout for establishing a network connection.
final
title → String?
A custom title to appear in the header bar at the top of the screen.
final
titleTextColor → Color?
The Color of the text in the title.
final

Methods

copyWith({Filter? filter, Color? titleTextColor, Color? promptTextColor, Color? closeButtonTintColor, Image? closeButtonImage, String? title, String? fontPath, Image? logoImage, Color? promptBackgroundColor, bool? promptRoundedCorners, Color? surroundColor, List<String>? certificates, Duration? timeout, bool? enableScreenshots, Orientation? orientation, Color? headerBackgroundColor, bool? disableExteriorEffects, GenuinePresenceAssuranceOptions? genuinePresenceAssurance, LivenessAssuranceOptions? livenessAssurance}) → Options
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited