UiOptions class

Options relating to the appearance of the iProov user interface.

Constructors

UiOptions({GenuinePresenceAssuranceUiOptions? genuinePresenceAssurance, LivenessAssuranceUiOptions? livenessAssurance, Filter? filter, Color? lineColor, Color? backgroundColor, Color? headerBackgroundColor, Color? footerBackgroundColor, Color? headerTextColor, Color? promptTextColor, bool? floatingPromptEnabled, String? title, String? fontPath, Image? logoImage, Image? closeButtonImage, Color? closeButtonTintColor, bool? enableScreenshots, Orientation? orientation, int? activityCompatibilityRequestCode, bool? floatingPromptRoundedCorners})
const

Properties

activityCompatibilityRequestCode → int?
An advanced option which can be used to enable "Activity compatibility mode" on Android with a specified request code. Use of this option is rarely required.
final
backgroundColor → Color?
The Color to use as the background for the canny effect.
final
closeButtonImage → Image?
A custom Image to be used for the close button which appears in the header bar at the top of the screen on the left hand side.
final
closeButtonTintColor → Color?
The Color to be applied to the closeButtonImage.
final
enableScreenshots → bool?
Whether screenshots should be allowed during the iProov scan process.
final
filter → Filter?
Filter to apply for the canny filter effect.
final
floatingPromptEnabled → bool?
Whether the prompt text should be floating above the camera preview or appear in the footer bar.
final
floatingPromptRoundedCorners → bool?
Whether the floating prompt (if enabled) should have rounded corners.
final
fontPath → String?
Path to the font to use for the iProov UI. The font must be added to your app (TTF or OTF formats are supported).
final
footerBackgroundColor → Color?
The Color to use as the background for the footer bar at the bottom of the screen.
final
genuinePresenceAssurance → GenuinePresenceAssuranceUiOptions?
UI options relating specifically to Genuine Presence Assurance (GPA).
final
hashCode → int
The hash code for this object.
no setterinherited
headerBackgroundColor → Color?
The Color to use as the background for the header bar at the top of the screen.
final
headerTextColor → Color?
The Color to use for the title text that appears in the header.
final
lineColor → Color?
The Color for the canny effect lines.
final
livenessAssurance → LivenessAssuranceUiOptions?
UI options relating specifically to Liveness Assurance (LA).
final
logoImage → Image?
A small logo Image to display in the header bar at the top of the screen on the right hand side.
final
orientation → Orientation?
Sets the orientation of the iProov UI.
final
promptTextColor → Color?
The Color to use for the prompt text that appears in the footer.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
title → String?
A custom title to appear in the header bar at the top of the screen.
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, dynamic>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited