GenuinePresenceAssuranceOptions class
Options relating to the appearance of the iProov user interface for GPA claims.
- Annotations
Constructors
Properties
- hashCode → int
-
The hash code for this object.
no setterinherited
- maxPitch → double?
-
The maximum deviation in pitch (in normalized units) to be applied for pose control.
Requires a compatible FaceDetector to be specified.
final
- maxRoll → double?
-
The maximum deviation in roll (in normalized units) to be applies for pose control.
Requires a compatible FaceDetector to be specified.
final
- maxYaw → double?
-
The maximum deviation in yaw (in normalized units) to be applied for pose control.
Requires a compatible FaceDetector to be specified.
final
- notReadyOvalStrokeColor → Color?
-
The Color to use for the oval stroke line when the scan is not ready to start.
final
- readyOvalStrokeColor → Color?
-
The Color to use for the oval stroke line when the scan is ready to start.
final
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited